@@ -1,5 +1,5 @@
 package App::JobLog::Log::Day;
-$App::JobLog::Log::Day::VERSION = '1.033';
+$App::JobLog::Log::Day::VERSION = '1.034';
 # ABSTRACT: collects events and vacation in a complete day
 
 
@@ -48,6 +48,9 @@ sub time_remaining {
 sub events { $_[0]->{events} }
 
 
+sub last_event { ( $_[0]->events || [] )->[-1] }
+
+
 sub vacation { $_[0]->{vacation} }
 
 
@@ -173,7 +176,7 @@ App::JobLog::Log::Day - collects events and vacation in a complete day
 
 =head1 VERSION
 
-version 1.033
+version 1.034
 
 =head1 DESCRIPTION
 
@@ -203,6 +206,10 @@ Determines how much work was done this day relative to what was expected.
 Returns reference to list of events occurring in this day. These are work
 events, not vacation.
 
+=head2 last_event
+
+Returns last event of the day, if any.
+
 =head2 vacation
 
 Returns reference to list of vacation events occurring in this day.
